@@ -11,11 +11,13 @@ from Crypto.Cipher import AES
 
 class Crypto(object):
     def __init__(self, key: str):
+        """crypto key, len must 16"""
         self.key: str = key
         self._length = 16
         self._mode: "AES.MODE_CBC" = AES.MODE_CBC
 
     def encrypt(self, raw_data: str) -> bytes:
+        """encrypt str to bytes"""
         new_crypto: "AES.new" = AES.new(self.key, self._mode, self.key)
         count: int = len(raw_data)
         salt: int = 0
@@ -26,6 +28,7 @@ class Crypto(object):
         return b2a_hex(encrypt_str)
 
     def decrypt(self, raw_byte: bytes) -> str:
+        """decrypt bytes to str"""
         new_crypto: "AES.new" = AES.new(self.key, self._mode, self.key)
         decrypt_pt: str = new_crypto.decrypt(a2b_hex(raw_byte)).decode()
         return decrypt_pt.rstrip("\0")
